@@ -7,11 +7,9 @@ def create_opts_parser(command):
     """
     Create parser for command-line options
     """
-    usage = "Usage: %prog host jobname [options]"
+    usage = "Usage: %prog host [jobname] [options]"
     desc = 'Run autojenkins to {0} a job.'.format(command)
     parser = optparse.OptionParser(description=desc, usage=usage)
-    #parser.add_option('jobname',
-    #                    help='the name of a job in jenkins')
     return parser
 
 
@@ -52,3 +50,24 @@ def delete_job(host, jobname):
     jenkins = Jenkins(host)
     response = jenkins.delete(jobname)
     print('Status: {0}'.format(response.status_code))
+
+def list_jobs(host):
+    """
+    List all jobs
+    """
+    COLOR = "\033[{0}m"
+    COLORCODE = { 
+        'blue': '1;34', 
+        'red': '1;31', 
+        'yellow': '1;33', 
+        'aborted': '1;37',
+        'disabled': '0;37',
+        'grey': '1;37',
+    }
+
+    print ("All jobs in {0}".format(host))
+    jenkins = Jenkins(host)
+    jobs = jenkins.all_jobs()
+    for name, color in jobs:
+        print(COLOR.format(COLORCODE[color.split('_')[0]]) + name)
+
